from setuptools import setup

setup(
    name='pyfilehandling',
    version='1.1.1',
    description='A Python package for file manipulation operations.',
    long_description='pyfilehandling is a Python package that provides functions and classes for handling file operations, including creating files and directories, reading and writing data, and more.',
    long_description_content_type='text/markdown',
    author='JeelDobariya',
    author_email='dobariyaj34@gmail.com',
    url='https://github.com/JeelDobariya38/pyfilehandling',
    packages=['pyfilehandling'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    keywords='file handling manipulation',
    project_urls={
        'Bug Tracker': 'https://github.com/JeelDobariya38/pyfilehandling/issues',
        'Documentation': 'https://jeeldobariya38.github.io/pyfilehandling/',
        'Source Code': 'https://github.com/JeelDobariya38/pyfilehandling',
    },
    license='MIT',
)
